.. image:: https://img.shields.io/pypi/v/gaftools.svg?branch=main
    :target: https://pypi.python.org/pypi/gaftools

.. image:: https://github.com/marschall-lab/gaftools/workflows/CI/badge.svg


gaftools
========

gaftools is a fast and comprehensive toolkit designed for processing pangenome alignments. It provides various functionalities such as
indexing, sorting, realignment, viewing and statistical analysis of rGFA-based GAF files.

`Link to GitHub <https://github.com/marschall-lab/gaftools/tree/main>`_

`Documentation <https://gaftools.readthedocs.io/>`_ is available on Read The Docs. Documentation can be locally built under :code:`docs` folder
using :code:`sphinx`. :code:`sphinx` is automatically installed when installing gaftools in `dev` mode.

`Preprint <https://www.biorxiv.org/content/10.1101/2024.12.10.627813v1>`_ is available on bioRxiv.

Features
--------

* Viewing GAF files based on user-defined regions or node IDs.
* Conversion of GAF format from unstable segment coordinates to stable coordinates and vice-versa.
* New tags for GFA files for ordering of bubbles and sorting GAF files.
* Post-processing GAF alignments using Wavefront Alignment and generating basic alignment statistics.
* Easy-to-install. Available in PyPI and bioconda.
* Open Source (MIT License)

Citation
--------

Pani, S., Dabbaghie, F., Marschall, T. & Söylev, A. gaftools: a toolkit for analyzing and manipulating pangenome alignments. (2024) doi:10.1101/2024.12.10.627813.
